/*!
 * \file    bool.h
 * \brief   Template meta-programming bool integral constant
 *
 * Copyright (C) 2018 Christos Choutouridis
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation, either version 3
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
#ifndef __utl_meta_bool_h__
#define __utl_meta_bool_h__

#include <utl/impl/impl.h>
#include <utl/meta/integral.h>

/*!
 * \ingroup meta
 * \defgroup bool
 * boolean constant type support header
 */
//! @{

namespace utl {

   //! bool_ type
   template<bool _v>
     using bool_ = integral_<bool, _v>;

   //! The type used as a compile-time boolean with true value.
   typedef bool_<true>  true_;

   //! The type used as a compile-time boolean with false value.
   typedef bool_<false> false_;

}

//! @}
#endif /* __utl_meta_bool_h__ */
